@@ -1,16 +1,10 @@
-use assert_cmd::prelude::*;
 use std::fs::File;
 use std::io::Read;
 use std::path::{Path, PathBuf};
-use std::process::Command;
 use std::str;
 
 use tempfile::TempDir;
 
-pub fn binary() -> Command {
-    Command::cargo_bin(env!("CARGO_PKG_NAME")).unwrap()
-}
-
 #[derive(Debug)]
 pub struct Project {
     pub(crate) root: TempDir,
